Class: AureEx::DepositCreate
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- AureEx::DepositCreate
- Defined in:
- lib/aure_ex/generated/models/deposit_create.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#amount ⇒ Object
Valor opcional em menor unidade USDT (quando aplicável).
-
#callback_url ⇒ Object
Returns the value of attribute callback_url.
-
#customer ⇒ Object
Returns the value of attribute customer.
-
#metadata ⇒ Object
Returns the value of attribute metadata.
-
#method ⇒ Object
Returns the value of attribute method.
-
#network ⇒ Object
Rede USDT (ex. tron.
-
#reference ⇒ Object
Returns the value of attribute reference.
-
#splits ⇒ Object
Returns the value of attribute splits.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ DepositCreate
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ DepositCreate
Initializes the object
104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 |
# File 'lib/aure_ex/generated/models/deposit_create.rb', line 104 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `AureEx::DepositCreate` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `AureEx::DepositCreate`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'method') self.method = attributes[:'method'] else self.method = 'usdt' end if attributes.key?(:'amount') self.amount = attributes[:'amount'] end if attributes.key?(:'network') self.network = attributes[:'network'] end if attributes.key?(:'reference') self.reference = attributes[:'reference'] else self.reference = nil end if attributes.key?(:'callback_url') self.callback_url = attributes[:'callback_url'] end if attributes.key?(:'customer') self.customer = attributes[:'customer'] end if attributes.key?(:'metadata') if (value = attributes[:'metadata']).is_a?(Hash) self. = value end end if attributes.key?(:'splits') if (value = attributes[:'splits']).is_a?(Array) self.splits = value end end end |
Instance Attribute Details
#amount ⇒ Object
Valor opcional em menor unidade USDT (quando aplicável)
21 22 23 |
# File 'lib/aure_ex/generated/models/deposit_create.rb', line 21 def amount @amount end |
#callback_url ⇒ Object
Returns the value of attribute callback_url.
28 29 30 |
# File 'lib/aure_ex/generated/models/deposit_create.rb', line 28 def callback_url @callback_url end |
#customer ⇒ Object
Returns the value of attribute customer.
30 31 32 |
# File 'lib/aure_ex/generated/models/deposit_create.rb', line 30 def customer @customer end |
#metadata ⇒ Object
Returns the value of attribute metadata.
32 33 34 |
# File 'lib/aure_ex/generated/models/deposit_create.rb', line 32 def @metadata end |
#method ⇒ Object
Returns the value of attribute method.
18 19 20 |
# File 'lib/aure_ex/generated/models/deposit_create.rb', line 18 def method @method end |
#network ⇒ Object
Rede USDT (ex. tron
24 25 26 |
# File 'lib/aure_ex/generated/models/deposit_create.rb', line 24 def network @network end |
#reference ⇒ Object
Returns the value of attribute reference.
26 27 28 |
# File 'lib/aure_ex/generated/models/deposit_create.rb', line 26 def reference @reference end |
#splits ⇒ Object
Returns the value of attribute splits.
34 35 36 |
# File 'lib/aure_ex/generated/models/deposit_create.rb', line 34 def splits @splits end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
73 74 75 |
# File 'lib/aure_ex/generated/models/deposit_create.rb', line 73 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
78 79 80 |
# File 'lib/aure_ex/generated/models/deposit_create.rb', line 78 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
59 60 61 62 63 64 65 66 67 68 69 70 |
# File 'lib/aure_ex/generated/models/deposit_create.rb', line 59 def self.attribute_map { :'method' => :'method', :'amount' => :'amount', :'network' => :'network', :'reference' => :'reference', :'callback_url' => :'callbackUrl', :'customer' => :'customer', :'metadata' => :'metadata', :'splits' => :'splits' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 |
# File 'lib/aure_ex/generated/models/deposit_create.rb', line 236 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
97 98 99 100 |
# File 'lib/aure_ex/generated/models/deposit_create.rb', line 97 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
83 84 85 86 87 88 89 90 91 92 93 94 |
# File 'lib/aure_ex/generated/models/deposit_create.rb', line 83 def self.openapi_types { :'method' => :'String', :'amount' => :'Integer', :'network' => :'String', :'reference' => :'String', :'callback_url' => :'String', :'customer' => :'CustomerInput', :'metadata' => :'Hash<String, Object>', :'splits' => :'Array<Hash<String, Object>>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
208 209 210 211 212 213 214 215 216 217 218 219 |
# File 'lib/aure_ex/generated/models/deposit_create.rb', line 208 def ==(o) return true if self.equal?(o) self.class == o.class && method == o.method && amount == o.amount && network == o.network && reference == o.reference && callback_url == o.callback_url && customer == o.customer && == o. && splits == o.splits end |
#eql?(o) ⇒ Boolean
223 224 225 |
# File 'lib/aure_ex/generated/models/deposit_create.rb', line 223 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
229 230 231 |
# File 'lib/aure_ex/generated/models/deposit_create.rb', line 229 def hash [method, amount, network, reference, callback_url, customer, , splits].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
161 162 163 164 165 166 167 168 169 170 171 172 173 |
# File 'lib/aure_ex/generated/models/deposit_create.rb', line 161 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @method.nil? invalid_properties.push('invalid value for "method", method cannot be nil.') end if @reference.nil? invalid_properties.push('invalid value for "reference", reference cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
258 259 260 261 262 263 264 265 266 267 268 269 270 |
# File 'lib/aure_ex/generated/models/deposit_create.rb', line 258 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
177 178 179 180 181 182 183 184 |
# File 'lib/aure_ex/generated/models/deposit_create.rb', line 177 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @method.nil? method_validator = EnumAttributeValidator.new('String', ["usdt"]) return false unless method_validator.valid?(@method) return false if @reference.nil? true end |