Class: AureEx::WithdrawalCreate

Inherits:
ApiModelBase show all
Defined in:
lib/aure_ex/generated/models/withdrawal_create.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ WithdrawalCreate

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
# File 'lib/aure_ex/generated/models/withdrawal_create.rb', line 73

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `AureEx::WithdrawalCreate` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `AureEx::WithdrawalCreate`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'amount')
    self.amount = attributes[:'amount']
  else
    self.amount = nil
  end

  if attributes.key?(:'network')
    self.network = attributes[:'network']
  end

  if attributes.key?(:'address')
    self.address = attributes[:'address']
  end

  if attributes.key?(:'reference')
    self.reference = attributes[:'reference']
  end

  if attributes.key?(:'callback_url')
    self.callback_url = attributes[:'callback_url']
  end

  if attributes.key?(:'metadata')
    if (value = attributes[:'metadata']).is_a?(Hash)
      self. = value
    end
  end
end

Instance Attribute Details

#addressObject

Endereço da carteira externa



23
24
25
# File 'lib/aure_ex/generated/models/withdrawal_create.rb', line 23

def address
  @address
end

#amountObject

Returns the value of attribute amount.



18
19
20
# File 'lib/aure_ex/generated/models/withdrawal_create.rb', line 18

def amount
  @amount
end

#callback_urlObject

Returns the value of attribute callback_url.



27
28
29
# File 'lib/aure_ex/generated/models/withdrawal_create.rb', line 27

def callback_url
  @callback_url
end

#metadataObject

Returns the value of attribute metadata.



29
30
31
# File 'lib/aure_ex/generated/models/withdrawal_create.rb', line 29

def 
  @metadata
end

#networkObject

Returns the value of attribute network.



20
21
22
# File 'lib/aure_ex/generated/models/withdrawal_create.rb', line 20

def network
  @network
end

#referenceObject

Returns the value of attribute reference.



25
26
27
# File 'lib/aure_ex/generated/models/withdrawal_create.rb', line 25

def reference
  @reference
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



44
45
46
# File 'lib/aure_ex/generated/models/withdrawal_create.rb', line 44

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



49
50
51
# File 'lib/aure_ex/generated/models/withdrawal_create.rb', line 49

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



32
33
34
35
36
37
38
39
40
41
# File 'lib/aure_ex/generated/models/withdrawal_create.rb', line 32

def self.attribute_map
  {
    :'amount' => :'amount',
    :'network' => :'network',
    :'address' => :'address',
    :'reference' => :'reference',
    :'callback_url' => :'callbackUrl',
    :'metadata' => :'metadata'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
# File 'lib/aure_ex/generated/models/withdrawal_create.rb', line 174

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



66
67
68
69
# File 'lib/aure_ex/generated/models/withdrawal_create.rb', line 66

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



54
55
56
57
58
59
60
61
62
63
# File 'lib/aure_ex/generated/models/withdrawal_create.rb', line 54

def self.openapi_types
  {
    :'amount' => :'Integer',
    :'network' => :'String',
    :'address' => :'String',
    :'reference' => :'String',
    :'callback_url' => :'String',
    :'metadata' => :'Hash<String, Object>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



148
149
150
151
152
153
154
155
156
157
# File 'lib/aure_ex/generated/models/withdrawal_create.rb', line 148

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      amount == o.amount &&
      network == o.network &&
      address == o.address &&
      reference == o.reference &&
      callback_url == o.callback_url &&
       == o.
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


161
162
163
# File 'lib/aure_ex/generated/models/withdrawal_create.rb', line 161

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



167
168
169
# File 'lib/aure_ex/generated/models/withdrawal_create.rb', line 167

def hash
  [amount, network, address, reference, callback_url, ].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



118
119
120
121
122
123
124
125
126
# File 'lib/aure_ex/generated/models/withdrawal_create.rb', line 118

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @amount.nil?
    invalid_properties.push('invalid value for "amount", amount cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



196
197
198
199
200
201
202
203
204
205
206
207
208
# File 'lib/aure_ex/generated/models/withdrawal_create.rb', line 196

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



130
131
132
133
134
# File 'lib/aure_ex/generated/models/withdrawal_create.rb', line 130

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @amount.nil?
  true
end